@@ -4,9 +4,10 @@
 
 // [[Rcpp::export]]
 Rcpp::LogicalVector rcpp_validate_json( Rcpp::StringVector json ) {
-  int n = json.size();
+  R_xlen_t n = json.size();
+  R_xlen_t i;
   Rcpp::LogicalVector res( n );
-  for ( int i = 0; i < n; i++ ) {
+  for ( i = 0; i < n; ++i ) {
     res[i] = jsonify::validate::validate_json( json[i] );
   }
   return res;
